LocalStoreProduct class

A fallback structure that mimics RevenueCat's StoreProduct

Constructors

LocalStoreProduct({required String identifier, required String title, required String description, required String priceString, required double price, required String currencyCode, required String subscriptionPeriod})

Properties

currencyCode String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
price double
final
priceString String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited